#!/bin/bash

#    Automates the packaging process of the software "doclifter" for
#    use with Zenwalk Linux.
#    
#    Copyright (C) 2008 Michael Verret
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

#    doclifter Home Page: http://www.catb.org/~esr/doclifter/
#    doclifter http://www.catb.org/~esr/doclifter/doclifter-2.3.tar.gz
#    doclifter Dependencies: "python"


#------------------( Unique Package Variables )


SOFTNAME='doclifter'
SOFTVERSION='2.3'
BUILDVERSION='52.1'
SOURCEVERSION="${SOFTVERSION}"
BUILDARCH='noarch'
BUILDCPU='i686'
DOCS="AUTHORS BUGS COPYING ChangeLog INSTALL LICENSE NEWS README"

SOURCES=" \
doclifter-2.3.tar.gz"


#------------------( Make Sure That We Have Everything )


for file in ${SOURCES} ; do
  echo -n "$file :"
  if [ -e $file ]; then
    echo " OK"
  else
    echo " MISSING !"
    exit 1
  fi
done


#------------------( Standard Variables & Routines )


BUILDIR=$(pwd)
cd ${BUILDIR}
PACKAGE="${SOFTNAME}-${SOFTVERSION}-${BUILDARCH}-${BUILDVERSION}"
INSTALLDIR="${BUILDIR}/${PACKAGE}"

rm -rf {${INSTALLDIR}*,${PACKAGE}*} 1>/dev/null 2>&1


#------------------( Build & Install The Software )


tar -xvzf ${SOURCES}

SOURCEDIR="${SOFTNAME}-${SOFTVERSION}"

cd ${SOURCEDIR}
	chown -R root:root .
	find . -perm 666 -exec chmod 644 {} \;
	find . -perm 664 -exec chmod 644 {} \;
	find . -perm 600 -exec chmod 644 {} \;
	find . -perm 444 -exec chmod 644 {} \;
	find . -perm 400 -exec chmod 644 {} \;
	find . -perm 440 -exec chmod 644 {} \;
	find . -perm 777 -exec chmod 755 {} \;
	find . -perm 775 -exec chmod 755 {} \;
	find . -perm 511 -exec chmod 755 {} \;
	find . -perm 711 -exec chmod 755 {} \;
	find . -perm 555 -exec chmod 755 {} \;

make doclifter.1

mkdir -p ${INSTALLDIR}/usr/bin
mkdir -p ${INSTALLDIR}/usr/man/man1/

cp doclifter manlifter ${INSTALLDIR}/usr/bin
cp doclifter.1 manlifter.1 ${INSTALLDIR}/usr/man/man1/

gzip -9 ${INSTALLDIR}/usr/man/man1/*

mkdir -p ${INSTALLDIR}/usr/doc/${SOFTNAME}-${SOFTVERSION}

cp ${DOCS} ${INSTALLDIR}/usr/doc/${SOFTNAME}-${SOFTVERSION}/ 1>/dev/null 2>&1
        
( cd ${INSTALLDIR}/usr/doc/${SOFTNAME}-${SOFTVERSION}/
      find . -name "*" -size 0c -exec rm {} \;
)

rm -rf ${BUILDIR}/${SOURCEDIR}


#------------------( Add Slack-desc )


mkdir -p ${INSTALLDIR}/install
cat <<EOF > ${INSTALLDIR}/install/slack-desc 
         |-----handy-ruler------------------------------------------------------|
doclifter: doclifter (Translates troff macros written docs to DocBook.)
doclifter:
doclifter: The doclifter program translates documents written in troff
doclifter: macros to DocBook.  Lifting documents from presentation level
doclifter: to semantic level is difficult, and a really good job requires
doclifter: human polishing, but this tool does about 95% of the work.
doclifter: It aims to do everything that can be mechanized, and to
doclifter: preserve in XML comments any troff-level information that
doclifter: might have structural implications. Also includes manlifter,
doclifter: a driver script that can be used to convert entire manual-page
doclifter: hierarchies.
EOF


#------------------( Add Buildscript )


mkdir -p ${INSTALLDIR}/usr/src/${SOFTNAME}-${SOFTVERSION}
cp ${BUILDIR}/build-${SOFTNAME}.sh ${INSTALLDIR}/usr/src/${SOFTNAME}-${SOFTVERSION}/build-${SOFTNAME}.sh


#------------------( Compress The Man Pages )


gzip -9 ${INSTALLDIR}/usr/man/*/* 1>/dev/null 2>&1


#------------------( Create dep file )


cat <<E1F > ${BUILDIR}/${PACKAGE}.dep 
python
E1F


#------------------( Compress The Package )


cd ${INSTALLDIR}
makepkg -l y -c n ${BUILDIR}/${PACKAGE}.tgz


#------------------( Calculate The MD5 Sum )

cd ${BUILDIR}
md5sum ${PACKAGE}.tgz > ${PACKAGE}.md5
rm -rf ${BUILDIR}/${PACKAGE}


#------------------( Changes )


# 2008-05-25	Created this package


